"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _classnames = _interopRequireDefault(require("classnames"));
var _bind = _interopRequireDefault(require("classnames/bind"));
var _terraThemeContext = _interopRequireDefault(require("terra-theme-context"));
var _uuid = require("uuid");
var _FieldsetModule = _interopRequireDefault(require("./Fieldset.module.scss"));
var _excluded = ["children", "help", "legend", "legendAttrs", "isLegendHidden", "required"];
/* eslint-disable react/jsx-boolean-value, jsx-a11y/label-has-for */
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } } return target; }
var cx = _bind.default.bind(_FieldsetModule.default);
var propTypes = {
  /**
   * Children the Field contains.
   */
  children: _propTypes.default.node,
  /**
   * Help element to display with other elements.
   */
  help: _propTypes.default.node,
  /**
   * Legend for the input group.
   */
  legend: _propTypes.default.string,
  /**
   * Attributes to attach to the legend.
   */
  // eslint-disable-next-line react/forbid-prop-types
  legendAttrs: _propTypes.default.object,
  /**
   * Determines whether the fieldset is required.
   */
  required: _propTypes.default.bool,
  /**
   * Whether or not the legend is visible. Use this prop to hide a legend while still creating it on the DOM for accessibility.
   */
  isLegendHidden: _propTypes.default.bool
};
var defaultProps = {
  legendAttrs: {},
  required: false,
  isLegendHidden: false
};
var Fieldset = function Fieldset(_ref) {
  var children = _ref.children,
    help = _ref.help,
    legend = _ref.legend,
    legendAttrs = _ref.legendAttrs,
    isLegendHidden = _ref.isLegendHidden,
    required = _ref.required,
    customProps = _objectWithoutProperties(_ref, _excluded);
  var theme = _react.default.useContext(_terraThemeContext.default);
  var fieldsetClasses = (0, _classnames.default)(cx(['fieldset', {
    'fieldset-required': required
  }, theme.className]), customProps.className);
  var legendClasses = cx(['legend', legendAttrs.className, {
    'legend-visually-hidden': isLegendHidden
  }]);
  var legendId = "terra-fieldset-legend-".concat((0, _uuid.v4)());
  var helpId = "terra-fieldset-help-".concat((0, _uuid.v4)());
  var addAriaHelpers = function addAriaHelpers(fieldsetChildren) {
    var cloneChildren = [];
    _react.default.Children.forEach(fieldsetChildren, function (child) {
      cloneChildren.push( /*#__PURE__*/_react.default.cloneElement(child, {
        'aria-labelledby': "".concat(legendId, " ").concat(helpId)
      }));
    });
    return cloneChildren;
  };
  return /*#__PURE__*/_react.default.createElement("fieldset", _extends({}, customProps, {
    className: fieldsetClasses
  }), legend && /*#__PURE__*/_react.default.createElement("legend", _extends({
    id: legendId
  }, legendAttrs, {
    className: legendClasses
  }), legend), help && /*#__PURE__*/_react.default.createElement("small", {
    id: helpId,
    className: cx('help-text'),
    tabIndex: "-1"
  }, help), /*#__PURE__*/_react.default.createElement("div", {
    className: cx('fieldset-children')
  }, (help || legend) && children ? addAriaHelpers(children) : children));
};
Fieldset.propTypes = propTypes;
Fieldset.defaultProps = defaultProps;
var _default = exports.default = Fieldset;